@@ -20,7 +20,7 @@ override('prepare', sub {
     super;
 
     foreach my $comp (@{ $self->components }) {
-        next unless defined($comp) && defined($comp->{component});
+        next unless defined($comp) && defined($comp->{component}) && $comp->{component}->visible;
         $comp->{component}->prepare();
     }
 });
@@ -32,7 +32,7 @@ override('draw', sub {
 
     foreach my $comp (@{ $self->components }) {
 
-        next unless defined($comp) && defined($comp->{component});
+        next unless defined($comp) && defined($comp->{component}) && $comp->{component}->visible;
         $comp->{component}->draw();
     }
 });
